@@ -11,12 +11,13 @@
 import argparse
 import logging
 import sys
+from http.server import HTTPServer
 from importlib import import_module
-
-from redis import Redis
+from threading import Thread
 
 from remotecv.error_handler import ErrorHandler
-from remotecv.utils import config
+from remotecv.utils import config, redis_client, SINGLE_NODE, SENTINEL
+from remotecv.healthcheck import HealthCheckHandler
 
 
 def start_pyres_worker():
@@ -24,12 +25,7 @@ def start_pyres_worker():
         UniqueWorker,
     )
 
-    redis = Redis(
-        host=config.redis_host,
-        port=config.redis_port,
-        db=config.redis_database,
-        password=config.redis_password,
-    )
+    redis = redis_client()
 
     def after_fork(_):
         config.error_handler.install_handler()
@@ -55,6 +51,18 @@ def start_celery_worker():
     celery_tasks.run_commands(config.extra_args, log_level=config.log_level)
 
 
+def start_http_server():
+    def serve_forever(httpd):
+        with httpd:
+            httpd.serve_forever()
+
+    httpd = HTTPServer(("", config.server_port), HealthCheckHandler)
+
+    thread = Thread(target=serve_forever, args=(httpd,))
+    thread.setDaemon(True)
+    thread.start()
+
+
 def main(params=None):
     if params is None:
         params = sys.argv[1:]
@@ -74,6 +82,32 @@ def main(params=None):
     conn_group.add_argument("--port", default=6379, type=int, help="Redis port")
     conn_group.add_argument("--database", default=0, type=int, help="Redis database")
     conn_group.add_argument("--password", default=None, help="Redis password")
+    conn_group.add_argument(
+        "--redis-mode",
+        default=SINGLE_NODE,
+        choices=[SINGLE_NODE, SENTINEL],
+        help="Redis mode",
+    )
+    conn_group.add_argument(
+        "--sentinel-instances",
+        default="localhost:26376",
+        help="Redis Sentinel instances e.g. 'localhost:26376,localhost:26377'",
+    )
+    conn_group.add_argument(
+        "--sentinel-password", default=None, help="Redis Sentinel password"
+    )
+    conn_group.add_argument(
+        "--master-instance", default=None, help="Redis Sentinel master instance"
+    )
+    conn_group.add_argument(
+        "--master-password", default=None, help="Redis Sentinel master password"
+    )
+    conn_group.add_argument(
+        "--socket-timeout",
+        default=10.0,
+        type=float,
+        help="Redis Sentinel socket timeout",
+    )
 
     conn_group = parser.add_argument_group("Celery/SQS Connection Arguments")
     conn_group.add_argument("--region", default="us-east-1", help="AWS SQS Region")
@@ -84,6 +118,16 @@ def main(params=None):
     )
 
     other_group = parser.add_argument_group("Other arguments")
+    other_group.add_argument(
+        "--server-port", default=8080, type=int, help="Server http port"
+    )
+    other_group.add_argument(
+        "--with-healthcheck",
+        default=False,
+        type=bool,
+        action=argparse.BooleanOptionalAction,
+        help="Start an healthchecker http endpoint",
+    )
     other_group.add_argument("-l", "--level", default="debug", help="Logging level")
     other_group.add_argument(
         "-o", "--loader", default="remotecv.http_loader", help="Loader used"
@@ -119,6 +163,12 @@ def main(params=None):
     config.redis_port = arguments.port
     config.redis_database = arguments.database
     config.redis_password = arguments.password
+    config.redis_mode = arguments.redis_mode
+    config.redis_sentinel_instances = arguments.sentinel_instances
+    config.redis_sentinel_password = arguments.sentinel_password
+    config.redis_sentinel_socket_timeout = arguments.socket_timeout
+    config.redis_sentinel_master_instance = arguments.master_instance
+    config.redis_sentinel_master_password = arguments.master_password
 
     config.region = arguments.region
     config.key_id = arguments.key_id
@@ -126,6 +176,7 @@ def main(params=None):
     config.polling_interval = arguments.polling_interval
 
     config.timeout = arguments.timeout
+    config.server_port = arguments.server_port
     config.log_level = arguments.level.upper()
     config.loader = import_module(arguments.loader)
     config.store = import_module(arguments.store)
@@ -136,6 +187,9 @@ def main(params=None):
 
     config.error_handler = ErrorHandler(arguments.sentry_url)
 
+    if arguments.with_healthcheck:
+        start_http_server()
+
     if arguments.backend == "pyres":
         start_pyres_worker()
     elif arguments.backend == "celery":
